// -*- c++ -*-

#ifndef DOMTREEPART_H
#define DOMTREEPART_H

#include <qdom.h>
#include <kparts/part.h>

class KListView;

/**
 * A KPart that displays a DOM tree in a KListView.
 */
class DOMTreePart : public KParts::ReadOnlyPart
{
    Q_OBJECT

public:
    DOMTreePart( QWidget *parent, const char *name=0 );
    ~DOMTreePart();

    QString filename() const { return m_file; }
    KListView *widget() const { return view; }

protected:
    virtual bool openFile();

    void buildTree( const QDomElement &node );
    void processChild( KListViewItem *i, const QDomNode &node );

    void buildBranch( KListViewItem *parent, const QDomElement &node );
    void buildBranch( KListViewItem *parent, const QDomDocumentType node );
    void buildBranch( KListViewItem *parent, const QDomProcessingInstruction &node );
    void buildBranch( KListViewItem *parent, const QDomText &node );
    void buildBranch( KListViewItem *parent, const QDomComment &node );


    /** Factory method for creating child items. */
    KListViewItem *createItem( KListViewItem *parent, const QDomElement &node );
    KListViewItem *createItem( KListViewItem *parent, const QDomDocumentType &node );
    KListViewItem *createItem( KListViewItem *parent, const QDomProcessingInstruction &node );
    KListViewItem *createItem( KListViewItem *parent, const QDomComment &node );
    KListViewItem *createItem( KListViewItem *parent, const QDomText &node );

private:
    KListView *view;
    QDomNode rootNode;
};

#endif // DOMTREEPART_H

// Local Variables:
// c-basic-offset: 4
// End:
